==> core-4.26.0.tgz: package/src/testing/BaseConsoleTest.js <==
/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Json, Options } from '@athenna/common';
import { AfterAll, BeforeAll } from '@athenna/test';
import { Ignite } from '@athenna/core';
import { TestCommand } from '@athenna/artisan/testing/plugins';
export class BaseConsoleTest {
    constructor() {
        this.env = Json.copy(process.env);
        this.config = Json.copy(Config.get());
        this.igniteOptions = {};
        this.artisanPath = Path.bootstrap(`artisan.${Path.ext()}`);
    }
    async baseBeforeAll() {
        TestCommand.setArtisanPath(this.artisanPath);
        this.ignite = await new Ignite().load(Path.toHref(Path.bootstrap(`test.${Path.ext()}`)), this.getIgniteOptions());
    }
    async baseAfterAll() {
        ioc.reconstruct();
        process.env = Json.copy(this.env);
        Object.keys(this.config).forEach(key => Config.set(key, Json.copy(this.config[key])));
    }
    getIgniteOptions() {
        return Options.create(this.igniteOptions, {
            bootLogs: false,
            loadConfigSafe: false,
            environments: ['test']
        });
    }
}
__decorate([
    BeforeAll(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], BaseConsoleTest.prototype, "baseBeforeAll", null);
__decorate([
    AfterAll(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], BaseConsoleTest.prototype, "baseAfterAll", null);

==> core-4.34.0.tgz: package/src/testing/BaseConsoleTest.js <==
/**
 * @athenna/core
 *
 * (c) João Lenon <lenon@athenna.io>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { AfterAll, BeforeAll } from '@athenna/test';
import { Path, Json, Options } from '@athenna/common';
import { Ignite } from '@athenna/core';
import { TestCommand } from '@athenna/artisan/testing/plugins';
export class BaseConsoleTest {
    constructor() {
        this.env = Json.copy(process.env);
        this.config = Json.copy(Config.get());
        this.igniteOptions = {};
        this.artisanPath = Path.bootstrap(`artisan.${Path.ext()}`);
    }
    async baseBeforeAll() {
        TestCommand.setArtisanPath(this.artisanPath);
        this.ignite = await new Ignite().load(Path.toHref(Path.bootstrap(`test.${Path.ext()}`)), this.getIgniteOptions());
    }
    async baseAfterAll() {
        ioc.reconstruct();
        process.env = Json.copy(this.env);
        Object.keys(this.config).forEach(key => Config.set(key, Json.copy(this.config[key])));
    }
    getIgniteOptions() {
        return Options.create(this.igniteOptions, {
            bootLogs: false,
            loadConfigSafe: false,
            environments: ['test']
        });
    }
}
__decorate([
    BeforeAll(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], BaseConsoleTest.prototype, "baseBeforeAll", null);
__decorate([
    AfterAll(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], BaseConsoleTest.prototype, "baseAfterAll", null);
